@@ -145,7 +145,7 @@ class App(object):
         '''
         self.errors.inner_html=""
         
-    def createSelectorGroupWithLabel(self,a,text:str):
+    def createSelectorGroupWithLabel(self,a,text:str,classes=""):
         '''
         create a selector Group with the given label
         '''
@@ -155,12 +155,12 @@ class App(object):
         #<span class="input-group-text" id="">First and last name</span>
         #</div>
         #selectorLabel=jp.Label(text=text,a=a,classes="form-label label")
-        selectorGroup=jp.Div(a=a,classes="input-group")
+        selectorGroup=jp.Div(a=a,classes=f"input-group {classes}")
         selectorGroupPrepend=jp.Div(a=selectorGroup,classes="input-group-prepend")
         selectorLabel=jp.Span(text=text,a=selectorGroupPrepend,classes="input-group-text")
         return selectorGroup,selectorLabel
         
-    def createSelect(self,labelText,value,change,a,**kwargs):
+    def createSelect(self,labelText,value,change,a,groupClasses="",**kwargs):
         '''
         create a select control with a label with the given text, the default value
         and a change onChange function having the parent a
@@ -171,16 +171,29 @@ class App(object):
             change(func): an onChange function
             a(object): the parent component of the Select control
         '''
-        selectorGroup,_selectorLabel=self.createSelectorGroupWithLabel(a, text=labelText)
+        selectorGroup,_selectorLabel=self.createSelectorGroupWithLabel(a, text=labelText,classes=groupClasses)
         select=jp.Select(a=selectorGroup,classes="form-select",value=value,change=change,**kwargs)
         return select
     
-    def createComboBox(self,labelText,a,**kwargs):
-        selectorGroup,_selectorLabel=self.createSelectorGroupWithLabel(a, text=labelText)
-        comboBox=ComboBox(a=selectorGroup,**kwargs)
-        return comboBox
+    def createComboBox(self,labelText,placeholder,change,a,size:int=30,groupClasses="",**kwargs):
+        '''
+        create a combobox with a label with the given text
+        a placeholder text and a change onChange function having the parent a
+        
+        Args:
+            labelText(str): the text for the label
+            placeholder(str): a placeholder value
+            change(func): an onChange function
+            a(object): the parent component of the Select control
+            size(int). the size of the input
+        '''
+        selectorGroup,selectorLabel=self.createSelectorGroupWithLabel(a, text=labelText,classes=groupClasses)
+        jpinput=ComboBox(a=selectorGroup,classes="form-input",size=size,placeholder=placeholder, **kwargs)
+        jpinput.on('input', change)
+        selectorLabel.for_component=jpinput
+        return jpinput
     
-    def createInput(self,labelText,placeholder,change,a,size:int=30, **kwargs):
+    def createInput(self,labelText,placeholder,change,a,size:int=30,groupClasses="",**kwargs):
         '''
         create an input control with a label with the given text
         a placeholder text and a change onChange function having the parent a
@@ -192,7 +205,7 @@ class App(object):
             a(object): the parent component of the Select control
             size(int). the size of the input
         '''
-        selectorGroup,selectorLabel=self.createSelectorGroupWithLabel(a, text=labelText)
+        selectorGroup,selectorLabel=self.createSelectorGroupWithLabel(a, text=labelText,classes=groupClasses)
         jpinput=jp.Input(a=selectorGroup,classes="form-input",size=size,placeholder=placeholder, **kwargs)
         jpinput.on('input', change)
         selectorLabel.for_component=jpinput
@@ -293,6 +306,9 @@ class DataList(jp.Div):
         cls = JustpyBaseComponent
         self.id = cls.next_id
         
+    def clear(self):
+        self.inner_html=""
+        
     def addOption(self,text,value):
         self.inner_html+=f"""<option value="{value}">{text}</option>"""
                  
@@ -310,7 +326,6 @@ class ComboBox(jp.Input):
         self.dataList=DataList(a=self)
         self.list=self.dataList.id
 
-
 class ProgressBar(jp.Div):
     """
     Displays a progressbar
